### 0.10.1 {small}`2024-04-03`

```{rubric} Bug fixes
```
* updates the behavior of `_check_gpu_X` for `require_cf`. It now only works for `pearson_residuals` calcs and corrects instead of throwing an error {pr}`154` {smaller}`S Dicks`
* Fixes the behavior of `pp.scale` with `mask_obs` and `max_value`. Now only the masked part gets clipped {pr}`158` {smaller}`S Dicks`

```{rubric} Misc
```
* Updates CI to work with `uv` {pr}`149` {smaller}`S Dicks`
* Adds `Codespell` {pr}`155` {smaller}`S Dicks`
